# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/circuit/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.cosmos.circuit.v1 import types_pb2 as cosmos_dot_circuit_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63osmos/circuit/v1/tx.proto\x12\x11\x63osmos.circuit.v1\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x1d\x63osmos/circuit/v1/types.proto\"\x81\x01\n\x1aMsgAuthorizeCircuitBreaker\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12\x33\n\x0bpermissions\x18\x03 \x01(\x0b\x32\x1e.cosmos.circuit.v1.Permissions:\x0c\x82\xe7\xb0*\x07granter\"5\n\"MsgAuthorizeCircuitBreakerResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"Q\n\x15MsgTripCircuitBreaker\x12\x11\n\tauthority\x18\x01 \x01(\t\x12\x15\n\rmsg_type_urls\x18\x02 \x03(\t:\x0e\x82\xe7\xb0*\tauthority\"0\n\x1dMsgTripCircuitBreakerResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"R\n\x16MsgResetCircuitBreaker\x12\x11\n\tauthority\x18\x01 \x01(\t\x12\x15\n\rmsg_type_urls\x18\x03 \x03(\t:\x0e\x82\xe7\xb0*\tauthority\"1\n\x1eMsgResetCircuitBreakerResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x32\xf4\x02\n\x03Msg\x12\x7f\n\x17\x41uthorizeCircuitBreaker\x12-.cosmos.circuit.v1.MsgAuthorizeCircuitBreaker\x1a\x35.cosmos.circuit.v1.MsgAuthorizeCircuitBreakerResponse\x12p\n\x12TripCircuitBreaker\x12(.cosmos.circuit.v1.MsgTripCircuitBreaker\x1a\x30.cosmos.circuit.v1.MsgTripCircuitBreakerResponse\x12s\n\x13ResetCircuitBreaker\x12).cosmos.circuit.v1.MsgResetCircuitBreaker\x1a\x31.cosmos.circuit.v1.MsgResetCircuitBreakerResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x1eZ\x1c\x63osmossdk.io/x/circuit/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.circuit.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\034cosmossdk.io/x/circuit/types'
  _globals['_MSGAUTHORIZECIRCUITBREAKER']._loaded_options = None
  _globals['_MSGAUTHORIZECIRCUITBREAKER']._serialized_options = b'\202\347\260*\007granter'
  _globals['_MSGTRIPCIRCUITBREAKER']._loaded_options = None
  _globals['_MSGTRIPCIRCUITBREAKER']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGRESETCIRCUITBREAKER']._loaded_options = None
  _globals['_MSGRESETCIRCUITBREAKER']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGAUTHORIZECIRCUITBREAKER']._serialized_start=106
  _globals['_MSGAUTHORIZECIRCUITBREAKER']._serialized_end=235
  _globals['_MSGAUTHORIZECIRCUITBREAKERRESPONSE']._serialized_start=237
  _globals['_MSGAUTHORIZECIRCUITBREAKERRESPONSE']._serialized_end=290
  _globals['_MSGTRIPCIRCUITBREAKER']._serialized_start=292
  _globals['_MSGTRIPCIRCUITBREAKER']._serialized_end=373
  _globals['_MSGTRIPCIRCUITBREAKERRESPONSE']._serialized_start=375
  _globals['_MSGTRIPCIRCUITBREAKERRESPONSE']._serialized_end=423
  _globals['_MSGRESETCIRCUITBREAKER']._serialized_start=425
  _globals['_MSGRESETCIRCUITBREAKER']._serialized_end=507
  _globals['_MSGRESETCIRCUITBREAKERRESPONSE']._serialized_start=509
  _globals['_MSGRESETCIRCUITBREAKERRESPONSE']._serialized_end=558
  _globals['_MSG']._serialized_start=561
  _globals['_MSG']._serialized_end=933
# @@protoc_insertion_point(module_scope)
