# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/delaymsg/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.delaymsg import delayed_message_pb2 as dydxprotocol_dot_delaymsg_dot_delayed__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dydxprotocol/delaymsg/query.proto\x12\x15\x64ydxprotocol.delaymsg\x1a\x1cgoogle/api/annotations.proto\x1a+dydxprotocol/delaymsg/delayed_message.proto\"\"\n QueryNextDelayedMessageIdRequest\"D\n!QueryNextDelayedMessageIdResponse\x12\x1f\n\x17next_delayed_message_id\x18\x01 \x01(\r\"!\n\x13QueryMessageRequest\x12\n\n\x02id\x18\x01 \x01(\r\"N\n\x14QueryMessageResponse\x12\x36\n\x07message\x18\x01 \x01(\x0b\x32%.dydxprotocol.delaymsg.DelayedMessage\"3\n\x1bQueryBlockMessageIdsRequest\x12\x14\n\x0c\x62lock_height\x18\x01 \x01(\r\"3\n\x1cQueryBlockMessageIdsResponse\x12\x13\n\x0bmessage_ids\x18\x01 \x03(\r2\x94\x04\n\x05Query\x12\xb4\x01\n\x14NextDelayedMessageId\x12\x37.dydxprotocol.delaymsg.QueryNextDelayedMessageIdRequest\x1a\x38.dydxprotocol.delaymsg.QueryNextDelayedMessageIdResponse\")\x82\xd3\xe4\x93\x02#\x12!/dydxprotocol/v4/delaymsg/next_id\x12\x92\x01\n\x07Message\x12*.dydxprotocol.delaymsg.QueryMessageRequest\x1a+.dydxprotocol.delaymsg.QueryMessageResponse\".\x82\xd3\xe4\x93\x02(\x12&/dydxprotocol/v4/delaymsg/message/{id}\x12\xbe\x01\n\x0f\x42lockMessageIds\x12\x32.dydxprotocol.delaymsg.QueryBlockMessageIdsRequest\x1a\x33.dydxprotocol.delaymsg.QueryBlockMessageIdsResponse\"B\x82\xd3\xe4\x93\x02<\x12:/dydxprotocol/v4/delaymsg/block/message_ids/{block_height}B<Z:github.com/dydxprotocol/v4-chain/protocol/x/delaymsg/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.delaymsg.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/delaymsg/types'
  _globals['_QUERY'].methods_by_name['NextDelayedMessageId']._loaded_options = None
  _globals['_QUERY'].methods_by_name['NextDelayedMessageId']._serialized_options = b'\202\323\344\223\002#\022!/dydxprotocol/v4/delaymsg/next_id'
  _globals['_QUERY'].methods_by_name['Message']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Message']._serialized_options = b'\202\323\344\223\002(\022&/dydxprotocol/v4/delaymsg/message/{id}'
  _globals['_QUERY'].methods_by_name['BlockMessageIds']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BlockMessageIds']._serialized_options = b'\202\323\344\223\002<\022:/dydxprotocol/v4/delaymsg/block/message_ids/{block_height}'
  _globals['_QUERYNEXTDELAYEDMESSAGEIDREQUEST']._serialized_start=135
  _globals['_QUERYNEXTDELAYEDMESSAGEIDREQUEST']._serialized_end=169
  _globals['_QUERYNEXTDELAYEDMESSAGEIDRESPONSE']._serialized_start=171
  _globals['_QUERYNEXTDELAYEDMESSAGEIDRESPONSE']._serialized_end=239
  _globals['_QUERYMESSAGEREQUEST']._serialized_start=241
  _globals['_QUERYMESSAGEREQUEST']._serialized_end=274
  _globals['_QUERYMESSAGERESPONSE']._serialized_start=276
  _globals['_QUERYMESSAGERESPONSE']._serialized_end=354
  _globals['_QUERYBLOCKMESSAGEIDSREQUEST']._serialized_start=356
  _globals['_QUERYBLOCKMESSAGEIDSREQUEST']._serialized_end=407
  _globals['_QUERYBLOCKMESSAGEIDSRESPONSE']._serialized_start=409
  _globals['_QUERYBLOCKMESSAGEIDSRESPONSE']._serialized_end=460
  _globals['_QUERY']._serialized_start=463
  _globals['_QUERY']._serialized_end=995
# @@protoc_insertion_point(module_scope)
