from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
GOPROTO_ENUM_PREFIX_FIELD_NUMBER: _ClassVar[int]
goproto_enum_prefix: _descriptor.FieldDescriptor
GOPROTO_ENUM_STRINGER_FIELD_NUMBER: _ClassVar[int]
goproto_enum_stringer: _descriptor.FieldDescriptor
ENUM_STRINGER_FIELD_NUMBER: _ClassVar[int]
enum_stringer: _descriptor.FieldDescriptor
ENUM_CUSTOMNAME_FIELD_NUMBER: _ClassVar[int]
enum_customname: _descriptor.FieldDescriptor
ENUMDECL_FIELD_NUMBER: _ClassVar[int]
enumdecl: _descriptor.FieldDescriptor
ENUMVALUE_CUSTOMNAME_FIELD_NUMBER: _ClassVar[int]
enumvalue_customname: _descriptor.FieldDescriptor
GOPROTO_GETTERS_ALL_FIELD_NUMBER: _ClassVar[int]
goproto_getters_all: _descriptor.FieldDescriptor
GOPROTO_ENUM_PREFIX_ALL_FIELD_NUMBER: _ClassVar[int]
goproto_enum_prefix_all: _descriptor.FieldDescriptor
GOPROTO_STRINGER_ALL_FIELD_NUMBER: _ClassVar[int]
goproto_stringer_all: _descriptor.FieldDescriptor
VERBOSE_EQUAL_ALL_FIELD_NUMBER: _ClassVar[int]
verbose_equal_all: _descriptor.FieldDescriptor
FACE_ALL_FIELD_NUMBER: _ClassVar[int]
face_all: _descriptor.FieldDescriptor
GOSTRING_ALL_FIELD_NUMBER: _ClassVar[int]
gostring_all: _descriptor.FieldDescriptor
POPULATE_ALL_FIELD_NUMBER: _ClassVar[int]
populate_all: _descriptor.FieldDescriptor
STRINGER_ALL_FIELD_NUMBER: _ClassVar[int]
stringer_all: _descriptor.FieldDescriptor
ONLYONE_ALL_FIELD_NUMBER: _ClassVar[int]
onlyone_all: _descriptor.FieldDescriptor
EQUAL_ALL_FIELD_NUMBER: _ClassVar[int]
equal_all: _descriptor.FieldDescriptor
DESCRIPTION_ALL_FIELD_NUMBER: _ClassVar[int]
description_all: _descriptor.FieldDescriptor
TESTGEN_ALL_FIELD_NUMBER: _ClassVar[int]
testgen_all: _descriptor.FieldDescriptor
BENCHGEN_ALL_FIELD_NUMBER: _ClassVar[int]
benchgen_all: _descriptor.FieldDescriptor
MARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
marshaler_all: _descriptor.FieldDescriptor
UNMARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
unmarshaler_all: _descriptor.FieldDescriptor
STABLE_MARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
stable_marshaler_all: _descriptor.FieldDescriptor
SIZER_ALL_FIELD_NUMBER: _ClassVar[int]
sizer_all: _descriptor.FieldDescriptor
GOPROTO_ENUM_STRINGER_ALL_FIELD_NUMBER: _ClassVar[int]
goproto_enum_stringer_all: _descriptor.FieldDescriptor
ENUM_STRINGER_ALL_FIELD_NUMBER: _ClassVar[int]
enum_stringer_all: _descriptor.FieldDescriptor
UNSAFE_MARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
unsafe_marshaler_all: _descriptor.FieldDescriptor
UNSAFE_UNMARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
unsafe_unmarshaler_all: _descriptor.FieldDescriptor
GOPROTO_EXTENSIONS_MAP_ALL_FIELD_NUMBER: _ClassVar[int]
goproto_extensions_map_all: _descriptor.FieldDescriptor
GOPROTO_UNRECOGNIZED_ALL_FIELD_NUMBER: _ClassVar[int]
goproto_unrecognized_all: _descriptor.FieldDescriptor
GOGOPROTO_IMPORT_FIELD_NUMBER: _ClassVar[int]
gogoproto_import: _descriptor.FieldDescriptor
PROTOSIZER_ALL_FIELD_NUMBER: _ClassVar[int]
protosizer_all: _descriptor.FieldDescriptor
COMPARE_ALL_FIELD_NUMBER: _ClassVar[int]
compare_all: _descriptor.FieldDescriptor
TYPEDECL_ALL_FIELD_NUMBER: _ClassVar[int]
typedecl_all: _descriptor.FieldDescriptor
ENUMDECL_ALL_FIELD_NUMBER: _ClassVar[int]
enumdecl_all: _descriptor.FieldDescriptor
GOPROTO_REGISTRATION_FIELD_NUMBER: _ClassVar[int]
goproto_registration: _descriptor.FieldDescriptor
MESSAGENAME_ALL_FIELD_NUMBER: _ClassVar[int]
messagename_all: _descriptor.FieldDescriptor
GOPROTO_SIZECACHE_ALL_FIELD_NUMBER: _ClassVar[int]
goproto_sizecache_all: _descriptor.FieldDescriptor
GOPROTO_UNKEYED_ALL_FIELD_NUMBER: _ClassVar[int]
goproto_unkeyed_all: _descriptor.FieldDescriptor
GOPROTO_GETTERS_FIELD_NUMBER: _ClassVar[int]
goproto_getters: _descriptor.FieldDescriptor
GOPROTO_STRINGER_FIELD_NUMBER: _ClassVar[int]
goproto_stringer: _descriptor.FieldDescriptor
VERBOSE_EQUAL_FIELD_NUMBER: _ClassVar[int]
verbose_equal: _descriptor.FieldDescriptor
FACE_FIELD_NUMBER: _ClassVar[int]
face: _descriptor.FieldDescriptor
GOSTRING_FIELD_NUMBER: _ClassVar[int]
gostring: _descriptor.FieldDescriptor
POPULATE_FIELD_NUMBER: _ClassVar[int]
populate: _descriptor.FieldDescriptor
STRINGER_FIELD_NUMBER: _ClassVar[int]
stringer: _descriptor.FieldDescriptor
ONLYONE_FIELD_NUMBER: _ClassVar[int]
onlyone: _descriptor.FieldDescriptor
EQUAL_FIELD_NUMBER: _ClassVar[int]
equal: _descriptor.FieldDescriptor
DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
description: _descriptor.FieldDescriptor
TESTGEN_FIELD_NUMBER: _ClassVar[int]
testgen: _descriptor.FieldDescriptor
BENCHGEN_FIELD_NUMBER: _ClassVar[int]
benchgen: _descriptor.FieldDescriptor
MARSHALER_FIELD_NUMBER: _ClassVar[int]
marshaler: _descriptor.FieldDescriptor
UNMARSHALER_FIELD_NUMBER: _ClassVar[int]
unmarshaler: _descriptor.FieldDescriptor
STABLE_MARSHALER_FIELD_NUMBER: _ClassVar[int]
stable_marshaler: _descriptor.FieldDescriptor
SIZER_FIELD_NUMBER: _ClassVar[int]
sizer: _descriptor.FieldDescriptor
UNSAFE_MARSHALER_FIELD_NUMBER: _ClassVar[int]
unsafe_marshaler: _descriptor.FieldDescriptor
UNSAFE_UNMARSHALER_FIELD_NUMBER: _ClassVar[int]
unsafe_unmarshaler: _descriptor.FieldDescriptor
GOPROTO_EXTENSIONS_MAP_FIELD_NUMBER: _ClassVar[int]
goproto_extensions_map: _descriptor.FieldDescriptor
GOPROTO_UNRECOGNIZED_FIELD_NUMBER: _ClassVar[int]
goproto_unrecognized: _descriptor.FieldDescriptor
PROTOSIZER_FIELD_NUMBER: _ClassVar[int]
protosizer: _descriptor.FieldDescriptor
COMPARE_FIELD_NUMBER: _ClassVar[int]
compare: _descriptor.FieldDescriptor
TYPEDECL_FIELD_NUMBER: _ClassVar[int]
typedecl: _descriptor.FieldDescriptor
MESSAGENAME_FIELD_NUMBER: _ClassVar[int]
messagename: _descriptor.FieldDescriptor
GOPROTO_SIZECACHE_FIELD_NUMBER: _ClassVar[int]
goproto_sizecache: _descriptor.FieldDescriptor
GOPROTO_UNKEYED_FIELD_NUMBER: _ClassVar[int]
goproto_unkeyed: _descriptor.FieldDescriptor
NULLABLE_FIELD_NUMBER: _ClassVar[int]
nullable: _descriptor.FieldDescriptor
EMBED_FIELD_NUMBER: _ClassVar[int]
embed: _descriptor.FieldDescriptor
CUSTOMTYPE_FIELD_NUMBER: _ClassVar[int]
customtype: _descriptor.FieldDescriptor
CUSTOMNAME_FIELD_NUMBER: _ClassVar[int]
customname: _descriptor.FieldDescriptor
JSONTAG_FIELD_NUMBER: _ClassVar[int]
jsontag: _descriptor.FieldDescriptor
MORETAGS_FIELD_NUMBER: _ClassVar[int]
moretags: _descriptor.FieldDescriptor
CASTTYPE_FIELD_NUMBER: _ClassVar[int]
casttype: _descriptor.FieldDescriptor
CASTKEY_FIELD_NUMBER: _ClassVar[int]
castkey: _descriptor.FieldDescriptor
CASTVALUE_FIELD_NUMBER: _ClassVar[int]
castvalue: _descriptor.FieldDescriptor
STDTIME_FIELD_NUMBER: _ClassVar[int]
stdtime: _descriptor.FieldDescriptor
STDDURATION_FIELD_NUMBER: _ClassVar[int]
stdduration: _descriptor.FieldDescriptor
WKTPOINTER_FIELD_NUMBER: _ClassVar[int]
wktpointer: _descriptor.FieldDescriptor
CASTREPEATED_FIELD_NUMBER: _ClassVar[int]
castrepeated: _descriptor.FieldDescriptor
