# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/clob/equity_tier_limit_config.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0dydxprotocol/clob/equity_tier_limit_config.proto\x12\x11\x64ydxprotocol.clob\x1a\x14gogoproto/gogo.proto\"\xbe\x01\n\x1c\x45quityTierLimitConfiguration\x12O\n\x1dshort_term_order_equity_tiers\x18\x01 \x03(\x0b\x32\".dydxprotocol.clob.EquityTierLimitB\x04\xc8\xde\x1f\x00\x12M\n\x1bstateful_order_equity_tiers\x18\x02 \x03(\x0b\x32\".dydxprotocol.clob.EquityTierLimitB\x04\xc8\xde\x1f\x00\"\x84\x01\n\x0f\x45quityTierLimit\x12\x62\n\x10usd_tnc_required\x18\x01 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12\r\n\x05limit\x18\x02 \x01(\rB8Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.equity_tier_limit_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_EQUITYTIERLIMITCONFIGURATION'].fields_by_name['short_term_order_equity_tiers']._loaded_options = None
  _globals['_EQUITYTIERLIMITCONFIGURATION'].fields_by_name['short_term_order_equity_tiers']._serialized_options = b'\310\336\037\000'
  _globals['_EQUITYTIERLIMITCONFIGURATION'].fields_by_name['stateful_order_equity_tiers']._loaded_options = None
  _globals['_EQUITYTIERLIMITCONFIGURATION'].fields_by_name['stateful_order_equity_tiers']._serialized_options = b'\310\336\037\000'
  _globals['_EQUITYTIERLIMIT'].fields_by_name['usd_tnc_required']._loaded_options = None
  _globals['_EQUITYTIERLIMIT'].fields_by_name['usd_tnc_required']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_EQUITYTIERLIMITCONFIGURATION']._serialized_start=94
  _globals['_EQUITYTIERLIMITCONFIGURATION']._serialized_end=284
  _globals['_EQUITYTIERLIMIT']._serialized_start=287
  _globals['_EQUITYTIERLIMIT']._serialized_end=419
# @@protoc_insertion_point(module_scope)
