from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class OrderRemovalReason(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ORDER_REMOVAL_REASON_UNSPECIFIED: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_EXPIRED: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_USER_CANCELED: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_UNDERCOLLATERALIZED: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_INTERNAL_ERROR: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_SELF_TRADE_ERROR: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_POST_ONLY_WOULD_CROSS_MAKER_ORDER: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_IMMEDIATE_OR_CANCEL_WOULD_REST_ON_BOOK: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_FOK_ORDER_COULD_NOT_BE_FULLY_FULLED: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_REDUCE_ONLY_RESIZE: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_INDEXER_EXPIRED: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_REPLACED: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_FULLY_FILLED: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_EQUITY_TIER: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_FINAL_SETTLEMENT: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_VIOLATES_ISOLATED_SUBACCOUNT_CONSTRAINTS: _ClassVar[OrderRemovalReason]
ORDER_REMOVAL_REASON_UNSPECIFIED: OrderRemovalReason
ORDER_REMOVAL_REASON_EXPIRED: OrderRemovalReason
ORDER_REMOVAL_REASON_USER_CANCELED: OrderRemovalReason
ORDER_REMOVAL_REASON_UNDERCOLLATERALIZED: OrderRemovalReason
ORDER_REMOVAL_REASON_INTERNAL_ERROR: OrderRemovalReason
ORDER_REMOVAL_REASON_SELF_TRADE_ERROR: OrderRemovalReason
ORDER_REMOVAL_REASON_POST_ONLY_WOULD_CROSS_MAKER_ORDER: OrderRemovalReason
ORDER_REMOVAL_REASON_IMMEDIATE_OR_CANCEL_WOULD_REST_ON_BOOK: OrderRemovalReason
ORDER_REMOVAL_REASON_FOK_ORDER_COULD_NOT_BE_FULLY_FULLED: OrderRemovalReason
ORDER_REMOVAL_REASON_REDUCE_ONLY_RESIZE: OrderRemovalReason
ORDER_REMOVAL_REASON_INDEXER_EXPIRED: OrderRemovalReason
ORDER_REMOVAL_REASON_REPLACED: OrderRemovalReason
ORDER_REMOVAL_REASON_FULLY_FILLED: OrderRemovalReason
ORDER_REMOVAL_REASON_EQUITY_TIER: OrderRemovalReason
ORDER_REMOVAL_REASON_FINAL_SETTLEMENT: OrderRemovalReason
ORDER_REMOVAL_REASON_VIOLATES_ISOLATED_SUBACCOUNT_CONSTRAINTS: OrderRemovalReason
