from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
NAME_FIELD_NUMBER: _ClassVar[int]
name: _descriptor.FieldDescriptor
MESSAGE_ENCODING_FIELD_NUMBER: _ClassVar[int]
message_encoding: _descriptor.FieldDescriptor
ENCODING_FIELD_NUMBER: _ClassVar[int]
encoding: _descriptor.FieldDescriptor
FIELD_NAME_FIELD_NUMBER: _ClassVar[int]
field_name: _descriptor.FieldDescriptor
DONT_OMITEMPTY_FIELD_NUMBER: _ClassVar[int]
dont_omitempty: _descriptor.FieldDescriptor
ONEOF_NAME_FIELD_NUMBER: _ClassVar[int]
oneof_name: _descriptor.FieldDescriptor
