# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/perpetuals/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.perpetuals import params_pb2 as dydxprotocol_dot_perpetuals_dot_params__pb2
from v4_proto.dydxprotocol.perpetuals import perpetual_pb2 as dydxprotocol_dot_perpetuals_dot_perpetual__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n dydxprotocol/perpetuals/tx.proto\x12\x17\x64ydxprotocol.perpetuals\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a$dydxprotocol/perpetuals/params.proto\x1a\'dydxprotocol/perpetuals/perpetual.proto\"\x91\x01\n\x12MsgCreatePerpetual\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12>\n\x06params\x18\x02 \x01(\x0b\x32(.dydxprotocol.perpetuals.PerpetualParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x1c\n\x1aMsgCreatePerpetualResponse\"\x98\x01\n\x13MsgSetLiquidityTier\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x44\n\x0eliquidity_tier\x18\x02 \x01(\x0b\x32&.dydxprotocol.perpetuals.LiquidityTierB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x1d\n\x1bMsgSetLiquidityTierResponse\"\xa1\x01\n\x18MsgUpdatePerpetualParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12H\n\x10perpetual_params\x18\x02 \x01(\x0b\x32(.dydxprotocol.perpetuals.PerpetualParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\"\n MsgUpdatePerpetualParamsResponse\";\n\x0e\x46undingPremium\x12\x14\n\x0cperpetual_id\x18\x01 \x01(\r\x12\x13\n\x0bpremium_ppm\x18\x02 \x01(\x05\"R\n\x12MsgAddPremiumVotes\x12<\n\x05votes\x18\x01 \x03(\x0b\x32\'.dydxprotocol.perpetuals.FundingPremiumB\x04\xc8\xde\x1f\x00\"\x1c\n\x1aMsgAddPremiumVotesResponse\"\x85\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x35\n\x06params\x18\x02 \x01(\x0b\x32\x1f.dydxprotocol.perpetuals.ParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse2\xdb\x04\n\x03Msg\x12s\n\x0f\x41\x64\x64PremiumVotes\x12+.dydxprotocol.perpetuals.MsgAddPremiumVotes\x1a\x33.dydxprotocol.perpetuals.MsgAddPremiumVotesResponse\x12s\n\x0f\x43reatePerpetual\x12+.dydxprotocol.perpetuals.MsgCreatePerpetual\x1a\x33.dydxprotocol.perpetuals.MsgCreatePerpetualResponse\x12v\n\x10SetLiquidityTier\x12,.dydxprotocol.perpetuals.MsgSetLiquidityTier\x1a\x34.dydxprotocol.perpetuals.MsgSetLiquidityTierResponse\x12\x85\x01\n\x15UpdatePerpetualParams\x12\x31.dydxprotocol.perpetuals.MsgUpdatePerpetualParams\x1a\x39.dydxprotocol.perpetuals.MsgUpdatePerpetualParamsResponse\x12j\n\x0cUpdateParams\x12(.dydxprotocol.perpetuals.MsgUpdateParams\x1a\x30.dydxprotocol.perpetuals.MsgUpdateParamsResponseB>Z<github.com/dydxprotocol/v4-chain/protocol/x/perpetuals/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.perpetuals.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dydxprotocol/v4-chain/protocol/x/perpetuals/types'
  _globals['_MSGCREATEPERPETUAL'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGCREATEPERPETUAL'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATEPERPETUAL'].fields_by_name['params']._loaded_options = None
  _globals['_MSGCREATEPERPETUAL'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCREATEPERPETUAL']._loaded_options = None
  _globals['_MSGCREATEPERPETUAL']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGSETLIQUIDITYTIER'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETLIQUIDITYTIER'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETLIQUIDITYTIER'].fields_by_name['liquidity_tier']._loaded_options = None
  _globals['_MSGSETLIQUIDITYTIER'].fields_by_name['liquidity_tier']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETLIQUIDITYTIER']._loaded_options = None
  _globals['_MSGSETLIQUIDITYTIER']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATEPERPETUALPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPERPETUALPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPERPETUALPARAMS'].fields_by_name['perpetual_params']._loaded_options = None
  _globals['_MSGUPDATEPERPETUALPARAMS'].fields_by_name['perpetual_params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPERPETUALPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPERPETUALPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGADDPREMIUMVOTES'].fields_by_name['votes']._loaded_options = None
  _globals['_MSGADDPREMIUMVOTES'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGCREATEPERPETUAL']._serialized_start=215
  _globals['_MSGCREATEPERPETUAL']._serialized_end=360
  _globals['_MSGCREATEPERPETUALRESPONSE']._serialized_start=362
  _globals['_MSGCREATEPERPETUALRESPONSE']._serialized_end=390
  _globals['_MSGSETLIQUIDITYTIER']._serialized_start=393
  _globals['_MSGSETLIQUIDITYTIER']._serialized_end=545
  _globals['_MSGSETLIQUIDITYTIERRESPONSE']._serialized_start=547
  _globals['_MSGSETLIQUIDITYTIERRESPONSE']._serialized_end=576
  _globals['_MSGUPDATEPERPETUALPARAMS']._serialized_start=579
  _globals['_MSGUPDATEPERPETUALPARAMS']._serialized_end=740
  _globals['_MSGUPDATEPERPETUALPARAMSRESPONSE']._serialized_start=742
  _globals['_MSGUPDATEPERPETUALPARAMSRESPONSE']._serialized_end=776
  _globals['_FUNDINGPREMIUM']._serialized_start=778
  _globals['_FUNDINGPREMIUM']._serialized_end=837
  _globals['_MSGADDPREMIUMVOTES']._serialized_start=839
  _globals['_MSGADDPREMIUMVOTES']._serialized_end=921
  _globals['_MSGADDPREMIUMVOTESRESPONSE']._serialized_start=923
  _globals['_MSGADDPREMIUMVOTESRESPONSE']._serialized_end=951
  _globals['_MSGUPDATEPARAMS']._serialized_start=954
  _globals['_MSGUPDATEPARAMS']._serialized_end=1087
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=1089
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=1114
  _globals['_MSG']._serialized_start=1117
  _globals['_MSG']._serialized_end=1720
# @@protoc_insertion_point(module_scope)
